package ch.iet_gibb.heatcalculator.model;

/**
 * The BurnSuper class represents a superclass for burning materials used in the heat calculator application.
 * It provides common functionality and attributes for burning materials.
 */
public abstract class Burn implements InterfaceBurn{
    /**
     * The type of wood
     */
    protected WoodTypes woodType;
    /**
     * The amount of energy in kilowatt-hours
     */
    protected double energy;

    public WoodTypes getWoodType() {
        return woodType;
    }
    public double getEnergy() {
        return energy;
    }

    public void setEnergy(double energy) {
        this.energy = energy;
    }

    /**
     * Constructs a BurnSuper object with the specified amount of energy.
     *
     * @param energy The amount of energy in kilowatt-hours.
     */
    public Burn(double energy) {
        this.energy = energy;
    }
    /**
     * Constructs a BurnSuper object with the specified type of wood and amount of energy.
     *
     * @param woodType The type of wood (buche, tanne, gemischt).
     * @param energy      The amount of energy in kilowatt-hours.
     */
    public Burn(WoodTypes woodType, double energy){
        setWoodType(woodType);
        this.energy = energy;
    }
    /**
     * Sets the type of wood for burning.
     * If the wood type is invalid, it sets an empty string.
     *
     * @param woodType The type of wood (buche, tanne, gemischt).
     */
    private void setWoodType(WoodTypes woodType) {
        if (woodType == WoodTypes.BUCHE || woodType == WoodTypes.TANNE || woodType == WoodTypes.GEMISCHT) {
            this.woodType = woodType;
        }
    }
        /**
         * Calculates the results of burning process.
         * Subclasses must implement this method to define specific behavior.
         */
        public abstract void calculateResults();

        /**
         * Sets the weight of the burning material in kilograms.
         * Subclasses must implement this method to define specific behavior.
         */
        public abstract void setWeightKg();

        /**
         * Sets the volume of the burning material in cubic meters.
         * Subclasses must implement this method to define specific behavior.
         */
        public abstract void setVolumeM3();
        public abstract String toString();
}
