package ch.iet_gibb.heatcalculator.model;

/**
 * The InterfaceBurn interface defines the contract for burning materials used in the heat calculator application.
 * It provides common functionality and attributes for burning materials.
 */
public interface InterfaceBurn {
    /**
     * Gets the type of wood.
     *
     * @return The type of wood.
     */
    WoodTypes getWoodType();

    /**
     * Gets the amount of energy in kilowatt-hours.
     *
     * @return The amount of energy.
     */
    double getEnergy();

    /**
     * Sets the amount of energy in kilowatt-hours.
     *
     * @param energy The amount of energy to set.
     */
    void setEnergy(double energy);

    /**
     * Calculates the results of the burning process.
     * Subclasses must implement this method to define specific behavior.
     */
    void calculateResults();

    /**
     * Sets the weight of the burning material in kilograms.
     * Subclasses must implement this method to define specific behavior.
     */
    void setWeightKg();

    /**
     * Sets the volume of the burning material in cubic meters.
     * Subclasses must implement this method to define specific behavior.
     */
    void setVolumeM3();

    /**
     * Converts the burning material to its string representation.
     *
     * @return The string representation of the burning material.
     */
    String toString();
}
